@@ -82,7 +82,8 @@ void BedIntersectPE::FindOverlaps(const BEDPE &a, vector<BED> &hits1, vector<BED
     // make sure we have a valid chromosome before we search
     if (a.chrom1 != ".") {
         // Find the quality hits between ***end1*** of the BEDPE and the B BED file
-        _bedB->FindOverlapsPerBin(a.chrom1, a.start1, a.end1, a.strand1, hits1, _sameStrand, _diffStrand);
+        _bedB->allHits(a.chrom1, a.start1, a.end1, a.strand1, 
+                       hits1, _sameStrand, _diffStrand, 0.0, false);
 
         vector<BED>::const_iterator h = hits1.begin();
         vector<BED>::const_iterator hitsEnd = hits1.end();
@@ -112,7 +113,8 @@ void BedIntersectPE::FindOverlaps(const BEDPE &a, vector<BED> &hits1, vector<BED
     // make sure we have a valid chromosome before we search
     if (a.chrom2 != ".") {
         // Now find the quality hits between ***end2*** of the BEDPE and the B BED file
-        _bedB->FindOverlapsPerBin(a.chrom2, a.start2, a.end2, a.strand2, hits2, _sameStrand, _diffStrand);
+        _bedB->allHits(a.chrom2, a.start2, a.end2, a.strand2, 
+                       hits2, _sameStrand, _diffStrand, 0.0, false);
 
         vector<BED>::const_iterator h = hits2.begin();
         vector<BED>::const_iterator hitsEnd = hits2.end();
@@ -199,8 +201,8 @@ bool BedIntersectPE::FindOneOrMoreOverlaps(const BEDPE &a, const string &type) {
 
     // Look for overlaps in end 1 assuming we have an aligned chromosome.
     if (a.chrom1 != ".") {
-        end1Found = _bedB->FindOneOrMoreOverlapsPerBin(a.chrom1, a.start1, a.end1, a.strand1,
-            _sameStrand, _diffStrand, _overlapFraction);
+        end1Found = _bedB->anyHits(a.chrom1, a.start1, a.end1, a.strand1,
+                                   _sameStrand, _diffStrand, _overlapFraction, false);
 
         // can we bail out without checking end2?
         if ((type == "either") && (end1Found == true)) return true;
@@ -211,8 +213,8 @@ bool BedIntersectPE::FindOneOrMoreOverlaps(const BEDPE &a, const string &type) {
 
     // Now look for overlaps in end 2 assuming we have an aligned chromosome.
     if (a.chrom2 != ".") {
-        end2Found = _bedB->FindOneOrMoreOverlapsPerBin(a.chrom2, a.start2, a.end2, a.strand2,
-            _sameStrand, _diffStrand, _overlapFraction);
+        end2Found = _bedB->anyHits(a.chrom2, a.start2, a.end2, a.strand2,
+                                   _sameStrand, _diffStrand, _overlapFraction, false);
 
         if ((type == "either") && (end2Found == true)) return true;
         else if ((type == "neither") && (end2Found == true)) return false;
@@ -273,7 +275,8 @@ void BedIntersectPE::FindSpanningOverlaps(const BEDPE &a, vector<BED> &hits, con
     spanLength = spanEnd - spanStart;
 
     // get the hits for the span
-    _bedB->FindOverlapsPerBin(a.chrom1, spanStart, spanEnd, a.strand1, hits, _sameStrand, _diffStrand);
+    _bedB->allHits(a.chrom1, spanStart, spanEnd, a.strand1, 
+                   hits, _sameStrand, _diffStrand, 0.0, false);
 
     vector<BED>::const_iterator h = hits.begin();
     vector<BED>::const_iterator hitsEnd = hits.end();
@@ -325,8 +328,8 @@ bool BedIntersectPE::FindOneOrMoreSpanningOverlaps(const BEDPE &a, const string
     }
     spanLength = spanEnd - spanStart;
 
-    overlapFound = _bedB->FindOneOrMoreOverlapsPerBin(a.chrom1, spanStart, spanEnd, a.strand1,
-        _sameStrand, _diffStrand, _overlapFraction);
+    overlapFound = _bedB->anyHits(a.chrom1, spanStart, spanEnd, a.strand1,
+                                  _sameStrand, _diffStrand, _overlapFraction, false);
 
     return overlapFound;
 }
